#!/usr/bin/python

import os

from setuptools import find_packages, setup

try:
    from subprocess import getstatusoutput
except ImportError:
    from commands import getstatusoutput


def bash_completion_dir():
    (sts, output) = getstatusoutput(
        'pkg-config --variable=completionsdir bash-completion')
    return output if not sts and output else '/etc/bash_completion.d'


project_dir = os.path.dirname(os.path.realpath(__file__))
requirements = os.path.join(project_dir, 'requirements.txt')
tests_requirements = os.path.join(project_dir, 'tests-requirements.txt')

with open(requirements, 'r') as f:
    install_requires = [line.strip() for line in f]
install_requires += [
    'distro',
]

with open(tests_requirements, 'r') as f:
    tests_require = [line.strip() for line in f]


setup(
    name="fedpkg",
    version="1.43",
    author="Dennis Gilmore",
    author_email="dgilmore@fedoraproject.org",
    description=("Fedora plugin to rpkg to manage "
                 "package sources in a git repository"),
    license="GPLv2+",
    url="https://pagure.io/fedpkg",
    packages=find_packages(),
    data_files=[(bash_completion_dir(), ['conf/bash-completion/fedpkg.bash']),
                ('/etc/rpkg', ['conf/etc/rpkg/fedpkg.conf',
                               'conf/etc/rpkg/fedpkg-stage.conf']),
                ('/usr/share/zsh/site-functions', ['conf/zsh-completion/_fedpkg']),
                ],

    setup_requires=['setuptools_scm', 'pytest-runner'],
    install_requires=install_requires,
    tests_require=tests_require,

    entry_points={
        'console_scripts': [
            'fedpkg = fedpkg.__main__:main',
            'fedpkg-stage = fedpkg.__main__:main',
        ],
    },

    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
)
